@@ -79,7 +79,7 @@ class RegistryGenerator:
 
     def setup_transfer(self, registry_file_location):
         # Available transfer options
-        transfer_options = ['S3', 'SFTP', 'SHAREPOINT']
+        transfer_options = ['S3', 'SFTP', 'SHAREPOINT', 'SMB']
         # User input -> selected option
         selected_transfer_option = ''
         # User display message
@@ -110,6 +110,8 @@ class RegistryGenerator:
                 self.generate_sftp_transfer(registry_file_location)
             case "sharepoint":
                 self.generate_sharepoint_transfer(registry_file_location)
+            case 'smb':
+                self.generate_smb_transfer(registry_file_location)
 
     def generate_sharepoint_transfer(self, tmp_registry_file_location):
         print("Generating Sharepoint Transfer entry...")
@@ -349,6 +351,56 @@ class RegistryGenerator:
         ET.indent(tmp_registry_file_tree, space="\t", level=0)
         tmp_registry_file_tree.write(tmp_registry_file_location)
 
+
+    def generate_smb_transfer(self, tmp_registry_file_location):
+        print("Generating SMB Transfer entry...")
+
+        smb_transfer_name = input("Please provide a name for your SMB Transfer.\nName: ")
+        while smb_transfer_name.strip() == "":
+            print("\nInvalid SMB transfer name provided!")
+            smb_transfer_name = input("Please provide a name for your SMB Transfer.\nName: ")
+
+        smb_url = input("Please provide a url for your SMB location.\nURL: ")
+        while smb_url.strip() == "":
+            print("\nInvalid SMB URL provided!")
+            smb_url = input("Please provide a url for your SMB location.\nURL: ")
+
+        confirmed = False
+        while not confirmed:
+            confirmation = input(
+                f"\nConfirm input: [y/n]\nSMB Transfer Name: {smb_transfer_name}"
+                f"\nSMB URL: {smb_url}\nIs this correct:")
+            match confirmation.lower():
+                case 'y':
+                    confirmed = True
+                    break
+                case 'yes':
+                    confirmed = True
+                    break
+                case 'n':
+                    confirmed = True
+                    print("Aborting...\n")
+                    self.setup_transfer(self.new_registry_file_tmp_location)
+                case 'no':
+                    confirmed = True
+                    print("Aborting...\n")
+                    self.setup_transfer(self.new_registry_file_tmp_location)
+                case _:
+                    print("Invalid input!")
+
+        smb_transfer_template = ET.XML(f'''
+            <destination>
+                <name>{smb_transfer_name}</name>
+                <type>smb</type>
+                <url>{smb_url}</url>
+            </destination>
+        ''')
+
+        tmp_registry_file_tree = ET.parse(tmp_registry_file_location)
+        tmp_registry_file_tree.find('.//destinations').append(smb_transfer_template)
+        ET.indent(tmp_registry_file_tree, space="\t", level=0)
+        tmp_registry_file_tree.write(tmp_registry_file_location)
+
     def update_project_with_new_registry(self, tmp_registry_file_location, composite_module_location,
                                          registry_module_location,
                                          artifact_name):
